@@ -8,7 +8,7 @@ package App::MatrixTool;
 use strict;
 use warnings;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use Getopt::Long qw( GetOptionsFromArray );
 use Future;
@@ -22,8 +22,11 @@ use Struct::Dumb qw( readonly_struct );
 
 use Protocol::Matrix::HTTP::Federation;
 
+require JSON;
+my $JSON_pretty = JSON->new->utf8(1)->pretty(1);
+
 my $opt_parser = Getopt::Long::Parser->new(
-   config => [qw( require_order )],
+   config => [qw( require_order no_ignore_case )],
 );
 
 =head1 NAME
@@ -296,6 +299,8 @@ sub client_token_store
    };
 }
 
+sub JSON_pretty { $JSON_pretty }
+
 ## Builtin commands
 
 package
