@@ -9,12 +9,13 @@ use strict;
 use warnings;
 use base qw( App::MatrixTool::SubCommands );
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use constant DESCRIPTION => "Commandline client utilities";
 use constant OPTIONS => (
    's|server=s' => "Server",
    'u|user-id=s' => "User ID",
+   'U|user-id-parameter=s' => "'user_id' query parameter override",
 );
 
 =head1 NAME
@@ -61,6 +62,11 @@ The following additional options are recognised
 
 User ID to supply the C<access_token> of.
 
+=item C<--user-id-parameter>, C<-U>
+
+User ID to set as the value of the C<user_id> HTTP query parameter. This is
+usually only useful for controlling application service ghosted users.
+
 =item C<--server>, C<-s>
 
 Server to connect to. Usually optional, as it is implied by the C<user-id> if
@@ -103,7 +109,7 @@ sub run
    my $self = shift;
    my ( $opts, @args ) = @_;
 
-   $self->{$_} //= $opts->{$_} for qw( server user_id );
+   $self->{$_} //= $opts->{$_} for qw( server user_id user_id_parameter );
 
    return $self->SUPER::run( @args );
 }
@@ -132,6 +138,10 @@ sub do_json
       $opts{params}{access_token} = $token if defined $token;
    }
 
+   if( $self->{user_id_parameter} ) {
+      $opts{params}{user_id} //= $self->{user_id_parameter};
+   }
+
    $client->request_json(
       server => $self->{server},
       method => $method,
