@@ -9,7 +9,7 @@ use strict;
 use warnings;
 use base qw( App::MatrixTool::Command::client );
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use constant DESCRIPTION => "Perform a direct JSON request";
 use constant ARGUMENTS => ( "path", "data?" );
@@ -17,9 +17,6 @@ use constant OPTIONS => (
    'm|method=s' => "HTTP method",
 );
 
-require JSON;
-my $JSON = JSON->new->utf8(1)->pretty(1);
-
 =head1 NAME
 
 matrixtool client json - Perform a direct JSON request
@@ -71,7 +68,7 @@ sub run
 
    my %opts;
 
-   $opts{content} = $JSON->decode( $data ) if defined $data;
+   $opts{content} = $self->JSON_pretty->decode( $data ) if defined $data;
 
    my $uri = URI->new( $pathquery );
    if( $uri->query_form ) {
@@ -81,7 +78,7 @@ sub run
    $self->do_json( $method, $uri->path, %opts )->then( sub {
       my ( $body, $response ) = @_;
 
-      print $JSON->encode( $body ) . "\n";
+      print $self->JSON_pretty->encode( $body ) . "\n";
       Future->done();
    });
 }
