@@ -42,7 +42,8 @@ EOF
 
 EOF
 
-   if( my $optspecs = $cmd->optspecs ) {
+   my $optspecs;
+   if( $optspecs = $cmd->optspecs and @$optspecs ) {
 
       print <<"EOF" =~ s/^ {9}//mgr;
          Options:
